@@ -159,6 +159,7 @@ classifiers = {
     "Framework :: Zope :: 5",
     "Framework :: Zope2",
     "Framework :: Zope3",
+    "Framework :: napari",
     "Framework :: tox",
     "Intended Audience :: Customer Service",
     "Intended Audience :: Developers",
@@ -411,6 +412,7 @@ classifiers = {
     "Programming Language :: Python :: 3 :: Only",
     "Programming Language :: Python :: 3.0",
     "Programming Language :: Python :: 3.1",
+    "Programming Language :: Python :: 3.10",
     "Programming Language :: Python :: 3.2",
     "Programming Language :: Python :: 3.3",
     "Programming Language :: Python :: 3.4",
